@@ -22,7 +22,12 @@ def get_geonames_country_data():
     return countries
 
 if __name__ == "__main__":
-    iso_names = dict([(str(c["ISO"].lower()), c["Country"])
-                    for c in get_geonames_country_data()])
+    country_metadata = dict([(c["Country"], c)
+                                for c in get_geonames_country_data()])
+    countries_sorted = sorted(country_metadata.keys())
+    iso_name_choices = [(str(country_metadata[country]["ISO"].lower()),
+                       country) for country in countries_sorted]
+    iso_names = dict(iso_name_choices)
     print("iso_names = %s" % iso_names)
+    print("iso_name_choices = %s" % iso_name_choices)
 
